package com.junmp.print.util;

import com.google.common.collect.Lists;
import com.google.gson.Gson;
import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonParser;
import com.google.gson.reflect.TypeToken;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class GsonUtil {

	private static Gson gson = null;

	static {
		gson = new Gson();
	}

	public static synchronized Gson getInstance() {
		if (null == gson) {
			gson = new Gson();
		}
		return gson;
	}

	/**
	 * JSON 转换为字符串
	 * 
	 * @param obj
	 * @return
	 */
	public static String toJson(Object obj) {
		return gson.toJson(obj);
	}

	/**
	 * 字符串转化为对象
	 * 
	 * @param json
	 * @param clzz
	 * @return
	 */
	public static <T> T toBean(String json, Class<T> clzz) {
		return gson.fromJson(json, clzz);
	}

	public static <T> Map<String, T> toMap(String json, Class<T> clz) {
		Map<String, JsonObject> map = gson.fromJson(json, new TypeToken<Map<String, JsonObject>>() {
		}.getType());
		Map<String, T> result = new HashMap<>();
		for (String key : map.keySet()) {
			result.put(key, gson.fromJson(map.get(key), clz));
		}
		return result;
	}

	public static Map<String, Object> toMap(String json) {
		Map<String, Object> map = gson.fromJson(json, new TypeToken<Map<String, Object>>() {
		}.getType());
		return map;
	}

	/**
	 * 转化为集合对象
	 * 
	 * @param json
	 * @param clz
	 * @return
	 */
	public static <T> List<T> toList(String json, Class<T> clz) {
		JsonArray array = new JsonParser().parse(json).getAsJsonArray();
		List<T> list = Lists.newArrayList();
		for (final JsonElement elem : array) {
			list.add(gson.fromJson(elem, clz));
		}
		return list;
	}

}
