package com.junmp.print.util;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * <pre>
 * 描述：
 * 版本：1.0
 * 日期：2018/5/23
 * 作者：wangq@junmp.com.cn
 * </pre>
 */

public class TimeUtil {

    /**
     * 时间格式为"yyyy-MM-dd"
     * @return
     */
    public static String getDate(){
        Date day=new Date();
        SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd");
        return df.format(day);
    }
    /**
     * 时间格式为"yyyyMMdd-HHmmss"
     * @return
     */
    public static String getDateLong(){
        Date day=new Date();
        SimpleDateFormat df = new SimpleDateFormat("yyyyMMdd-HHmmss");
        return df.format(day);
    }
    /**
     * 时间格式为"yyyyMMddhhmmss"
     * @return
     */
    public static String getDateLongNo(){
        Date day=new Date();
        SimpleDateFormat df = new SimpleDateFormat("yyyyMMddHHmmss");
        return df.format(day);
    }

    /**
     * 获取精确到秒的时间戳
     * @return
     */
    public static int getSecondTimestamp(Date date){
        if (null == date) {
            return 0;
        }
        String timestamp = String.valueOf(date.getTime());
        int length = timestamp.length();
        if (length > 3) {
            return Integer.valueOf(timestamp.substring(0,length-3));
        } else {
            return 0;
        }
    }

    /**
     * 获取精确到毫秒的时间戳
     * @return
     */
    public static Long getMillTimestamp(Long time){
        if (null == time) {
            return 0l;
        }
        String timestamp = String.valueOf(time);
        timestamp = timestamp+"000";
        return Long.parseLong(timestamp);
    }

    /**
     * 数据库中的时间(int 秒数)转换为时间格式为"yyyy-MM-dd HH:mm:ss"
     * @return
     */
    public static String getDateString(Integer secondTime){
        if (0 == secondTime) {
            return "";
        }
        Long millSec = secondTime.longValue()*1000;
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date date = new Date(millSec);
        return sdf.format(date);
    }

    /**
     * 数据库中的时间(int 秒数)转换为时间格式为"yyyy-MM-dd"
     * @return
     */
    public static String getDateStringShort(Integer secondTime){
        if (0 == secondTime) {
            return "";
        }
        Long millSec = secondTime.longValue()*1000;
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        Date date = new Date(millSec);
        return sdf.format(date);
    }

    /**
     * 数据库中的时间(int 秒数)转换为时间格式为"yyyyMMdd"
     * @return
     */
    public static String getDateStringShortSix(Integer secondTime){
        if (0 == secondTime) {
            return "";
        }
        Long millSec = secondTime.longValue()*1000;
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMdd");
        Date date = new Date(millSec);
        return sdf.format(date);
    }


    /**
     * "yyyy-MM-dd HH-mm-ss" 转换为秒数
     * @return
     */
    public static Integer getDateInt(String date){
        long time = 0l;
        int timeInt = 0;
        if (date.equals("")) {
            return 0;
        }
        //输入日期，转化为毫秒数，用DATE方法()
        /**
         * 先用SimpleDateFormat.parse() 方法将日期字符串转化为Date格式
         * 通过Date.getTime()方法，将其转化为毫秒数
         */
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH-mm-ss");//24小时制
//      SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd hh-mm-ss");//12小时制
        try {
            time = simpleDateFormat.parse(date).getTime()/1000;
            timeInt = (int) time;
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return timeInt;
    }


    /**
     * 时间格式
     * @return
     */
    public static String getDateString(int year,int monthOfYear,int dayOfMonth){
        String strmMonthOfYear = Integer.toString(monthOfYear);
        String strmDayOfMonth = Integer.toString(dayOfMonth);
        if(monthOfYear<10){
            strmMonthOfYear = "0"+strmMonthOfYear;
        }
        if(dayOfMonth<10){
            strmDayOfMonth = "0"+strmDayOfMonth;
        }
        return year + "-" + strmMonthOfYear + "-" + strmDayOfMonth ;
    }

    /*
   * 将秒数转为时分秒
   * */
    public static String changeTime(int second) {
        int h = 0;
        int d = 0;
        int s = 0;
        int temp = second % 3600;
        if (second > 3600) {
            h = second / 3600;
            if (temp != 0) {
                if (temp > 60) {
                    d = temp / 60;
                    if (temp % 60 != 0) {
                        s = temp % 60;
                    }
                } else {
                    s = temp;
                }
            }
        } else {
            d = second / 60;
            if (second % 60 != 0) {
                s = second % 60;
            }
        }
        return h + ":" + d + ":" + s + "";
    }


}
